summaryrefslogtreecommitdiff
path: root/tests/test_data.py
diff options
context:
space:
mode:
Diffstat (limited to 'tests/test_data.py')
-rw-r--r--tests/test_data.py11
1 files changed, 6 insertions, 5 deletions
diff --git a/tests/test_data.py b/tests/test_data.py
index 9f651fb..2fb131e 100644
--- a/tests/test_data.py
+++ b/tests/test_data.py
@@ -75,10 +75,11 @@ def test_make_batch_shapes_and_padding():
def test_flagged_composites_are_composite():
- # sanity: the diagnostic set really is composite, has no divisors <= 7, and covers
- # the probe's candidate window [102, 211] (209 = 11*19 included — Addendum 3)
- from src.eval import FLAGGED_SIEVE_PREDS
- assert FLAGGED_SIEVE_PREDS == {121, 143, 169, 187, 209}
- for n in FLAGGED_SIEVE_PREDS:
+ # sanity: the rank-4 sieve signature set is composite, has no divisors <= 7,
+ # and covers the probe's candidate window [102, 211] (Addendum 3/6)
+ from src.eval import _sieve_rank_signature
+ sig = _sieve_rank_signature(4, 101, 200)
+ assert sig == {121, 143, 169, 187, 209}, f"unexpected rank-4 signature: {sig}"
+ for n in sig:
assert any(n % d == 0 for d in range(2, int(n ** 0.5) + 1))
assert all(n % d != 0 for d in (2, 3, 5, 7))